ProcessReader

Struct ProcessReader 

pub struct ProcessReader<'a> { /* private fields */ }

Implementations

Source

impl<'a> ProcessReader<'a>

pub fn new(process_inspector: &'a ProcessInspector) -> Self

pub fn for_virtual_mem(process_inspector: &'a ProcessInspector) -> Self

pub fn for_file(process_inspector: &'a ProcessInspector) -> Result<Self, Error>

pub fn for_ptrace(process_inspector: &'a ProcessInspector) -> Self

pub fn read( &self, src: usize, dst: &mut [u8], ) -> Result<usize, CopyFromProcessError>

Read memory from the process into the given buffer.

Returns the number of bytes read.

pub fn find_module( &self, module_name: &str, ) -> Result<ProcessModuleMemoryReader<'_>, FindModuleError>

Find the address at which a module with the given name is loaded in the process.

Source

impl ProcessReader<'_>

pub fn read_to_vec( &self, src: usize, length: NonZeroUsize, ) -> Result<Vec<u8>, CopyFromProcessError>

pub fn read_all( &self, src: usize, dst: &mut [u8], ) -> Result<(), CopyFromProcessError>

pub fn read_all_to_vec( &self, src: usize, length: usize, ) -> Result<Vec<u8>, CopyFromProcessError>

pub fn copy_nul_terminated_string( &self, address: usize, ) -> Result<CString, CopyFromProcessError>

pub fn copy_object_uninit<T>( &self, src: usize, ) -> Result<MaybeUninit<T>, CopyFromProcessError>

pub unsafe fn copy_object<T>( &self, src: usize, ) -> Result<T, CopyFromProcessError>

Safety

The caller must ensure that the object will be in an initialized, valid state.

pub fn copy_array_uninit<T>( &self, src: usize, num: usize, ) -> Result<Vec<MaybeUninit<T>>, CopyFromProcessError>

pub unsafe fn copy_array<T>( &self, src: usize, num: usize, ) -> Result<Vec<T>, CopyFromProcessError>

Safety

The caller must ensure that the objects will be in an initialized, valid state.